numpy.ndenumerate
=================

.. currentmodule:: numpy

.. autoclass:: ndenumerate

   

   .. HACK
      .. autosummary::
         :toctree:
      
         ndenumerate.__init__
         ndenumerate.next



   

